# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['HttpFarmServerArgs', 'HttpFarmServer']

@pulumi.input_type
class HttpFarmServerArgs:
    def __init__(__self__, *,
                 address: pulumi.Input[builtins.str],
                 farm_id: pulumi.Input[builtins.int],
                 service_name: pulumi.Input[builtins.str],
                 status: pulumi.Input[builtins.str],
                 backup: Optional[pulumi.Input[builtins.bool]] = None,
                 chain: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 on_marked_down: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 probe: Optional[pulumi.Input[builtins.bool]] = None,
                 proxy_protocol_version: Optional[pulumi.Input[builtins.str]] = None,
                 ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a HttpFarmServer resource.
        :param pulumi.Input[builtins.str] address: Address of the backend server (IP from either internal or OVHcloud network)
        :param pulumi.Input[builtins.int] farm_id: ID of the farm this server is attached to
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] status: backend status - `active` or `inactive`
        :param pulumi.Input[builtins.bool] backup: is it a backup server used in case of failure of all the non-backup backends
        :param pulumi.Input[builtins.str] display_name: Label for the server
        :param pulumi.Input[builtins.str] on_marked_down: enable action when backend marked down. (`shutdown-sessions`)
        :param pulumi.Input[builtins.int] port: Port that backend will respond on
        :param pulumi.Input[builtins.bool] probe: defines if backend will be probed to determine health and keep as active in farm if healthy
        :param pulumi.Input[builtins.str] proxy_protocol_version: version of the PROXY protocol used to pass origin connection information from loadbalancer to receiving service (`v1`, `v2`, `v2-ssl`, `v2-ssl-cn`)
        :param pulumi.Input[builtins.bool] ssl: is the connection ciphered with SSL (TLS)
        :param pulumi.Input[builtins.int] weight: used in loadbalancing algorithm
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "farm_id", farm_id)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "status", status)
        if backup is not None:
            pulumi.set(__self__, "backup", backup)
        if chain is not None:
            pulumi.set(__self__, "chain", chain)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if on_marked_down is not None:
            pulumi.set(__self__, "on_marked_down", on_marked_down)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if probe is not None:
            pulumi.set(__self__, "probe", probe)
        if proxy_protocol_version is not None:
            pulumi.set(__self__, "proxy_protocol_version", proxy_protocol_version)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Input[builtins.str]:
        """
        Address of the backend server (IP from either internal or OVHcloud network)
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="farmId")
    def farm_id(self) -> pulumi.Input[builtins.int]:
        """
        ID of the farm this server is attached to
        """
        return pulumi.get(self, "farm_id")

    @farm_id.setter
    def farm_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "farm_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[builtins.str]:
        """
        backend status - `active` or `inactive`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def backup(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        is it a backup server used in case of failure of all the non-backup backends
        """
        return pulumi.get(self, "backup")

    @backup.setter
    def backup(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "backup", value)

    @property
    @pulumi.getter
    def chain(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "chain")

    @chain.setter
    def chain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "chain", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Label for the server
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="onMarkedDown")
    def on_marked_down(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        enable action when backend marked down. (`shutdown-sessions`)
        """
        return pulumi.get(self, "on_marked_down")

    @on_marked_down.setter
    def on_marked_down(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "on_marked_down", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Port that backend will respond on
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def probe(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        defines if backend will be probed to determine health and keep as active in farm if healthy
        """
        return pulumi.get(self, "probe")

    @probe.setter
    def probe(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "probe", value)

    @property
    @pulumi.getter(name="proxyProtocolVersion")
    def proxy_protocol_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        version of the PROXY protocol used to pass origin connection information from loadbalancer to receiving service (`v1`, `v2`, `v2-ssl`, `v2-ssl-cn`)
        """
        return pulumi.get(self, "proxy_protocol_version")

    @proxy_protocol_version.setter
    def proxy_protocol_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "proxy_protocol_version", value)

    @property
    @pulumi.getter
    def ssl(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        is the connection ciphered with SSL (TLS)
        """
        return pulumi.get(self, "ssl")

    @ssl.setter
    def ssl(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ssl", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        used in loadbalancing algorithm
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "weight", value)


@pulumi.input_type
class _HttpFarmServerState:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 backup: Optional[pulumi.Input[builtins.bool]] = None,
                 chain: Optional[pulumi.Input[builtins.str]] = None,
                 cookie: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 farm_id: Optional[pulumi.Input[builtins.int]] = None,
                 on_marked_down: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 probe: Optional[pulumi.Input[builtins.bool]] = None,
                 proxy_protocol_version: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering HttpFarmServer resources.
        :param pulumi.Input[builtins.str] address: Address of the backend server (IP from either internal or OVHcloud network)
        :param pulumi.Input[builtins.bool] backup: is it a backup server used in case of failure of all the non-backup backends
        :param pulumi.Input[builtins.str] cookie: Value of the stickiness cookie used for this backend.
        :param pulumi.Input[builtins.str] display_name: Label for the server
        :param pulumi.Input[builtins.int] farm_id: ID of the farm this server is attached to
        :param pulumi.Input[builtins.str] on_marked_down: enable action when backend marked down. (`shutdown-sessions`)
        :param pulumi.Input[builtins.int] port: Port that backend will respond on
        :param pulumi.Input[builtins.bool] probe: defines if backend will be probed to determine health and keep as active in farm if healthy
        :param pulumi.Input[builtins.str] proxy_protocol_version: version of the PROXY protocol used to pass origin connection information from loadbalancer to receiving service (`v1`, `v2`, `v2-ssl`, `v2-ssl-cn`)
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.bool] ssl: is the connection ciphered with SSL (TLS)
        :param pulumi.Input[builtins.str] status: backend status - `active` or `inactive`
        :param pulumi.Input[builtins.int] weight: used in loadbalancing algorithm
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if backup is not None:
            pulumi.set(__self__, "backup", backup)
        if chain is not None:
            pulumi.set(__self__, "chain", chain)
        if cookie is not None:
            pulumi.set(__self__, "cookie", cookie)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if farm_id is not None:
            pulumi.set(__self__, "farm_id", farm_id)
        if on_marked_down is not None:
            pulumi.set(__self__, "on_marked_down", on_marked_down)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if probe is not None:
            pulumi.set(__self__, "probe", probe)
        if proxy_protocol_version is not None:
            pulumi.set(__self__, "proxy_protocol_version", proxy_protocol_version)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Address of the backend server (IP from either internal or OVHcloud network)
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter
    def backup(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        is it a backup server used in case of failure of all the non-backup backends
        """
        return pulumi.get(self, "backup")

    @backup.setter
    def backup(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "backup", value)

    @property
    @pulumi.getter
    def chain(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "chain")

    @chain.setter
    def chain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "chain", value)

    @property
    @pulumi.getter
    def cookie(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Value of the stickiness cookie used for this backend.
        """
        return pulumi.get(self, "cookie")

    @cookie.setter
    def cookie(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cookie", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Label for the server
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="farmId")
    def farm_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        ID of the farm this server is attached to
        """
        return pulumi.get(self, "farm_id")

    @farm_id.setter
    def farm_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "farm_id", value)

    @property
    @pulumi.getter(name="onMarkedDown")
    def on_marked_down(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        enable action when backend marked down. (`shutdown-sessions`)
        """
        return pulumi.get(self, "on_marked_down")

    @on_marked_down.setter
    def on_marked_down(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "on_marked_down", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Port that backend will respond on
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def probe(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        defines if backend will be probed to determine health and keep as active in farm if healthy
        """
        return pulumi.get(self, "probe")

    @probe.setter
    def probe(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "probe", value)

    @property
    @pulumi.getter(name="proxyProtocolVersion")
    def proxy_protocol_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        version of the PROXY protocol used to pass origin connection information from loadbalancer to receiving service (`v1`, `v2`, `v2-ssl`, `v2-ssl-cn`)
        """
        return pulumi.get(self, "proxy_protocol_version")

    @proxy_protocol_version.setter
    def proxy_protocol_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "proxy_protocol_version", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def ssl(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        is the connection ciphered with SSL (TLS)
        """
        return pulumi.get(self, "ssl")

    @ssl.setter
    def ssl(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ssl", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        backend status - `active` or `inactive`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        used in loadbalancing algorithm
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "weight", value)


class HttpFarmServer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 backup: Optional[pulumi.Input[builtins.bool]] = None,
                 chain: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 farm_id: Optional[pulumi.Input[builtins.int]] = None,
                 on_marked_down: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 probe: Optional[pulumi.Input[builtins.bool]] = None,
                 proxy_protocol_version: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Creates a backend server entry linked to HTTP loadbalancing group (farm)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        lb = ovh.IpLoadBalancing.get_ip_load_balancing(service_name="ip-1.2.3.4",
            state="ok")
        farmname = ovh.ip_load_balancing.HttpFarm("farmname",
            service_name=lb.service_name,
            port=8080,
            zone="all")
        backend = ovh.ip_load_balancing.HttpFarmServer("backend",
            service_name=lb.service_name,
            farm_id=farmname.id,
            display_name="mybackend",
            address="4.5.6.7",
            status="active",
            port=80,
            proxy_protocol_version="v2",
            weight=2,
            probe=True,
            ssl=False,
            backup=True)
        ```

        ## Import

        HTTP farm server can be imported using the following format `service_name`, the `id` of the farm and the `id` of the server separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:IpLoadBalancing/httpFarmServer:HttpFarmServer backend service_name/farm_id/server_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] address: Address of the backend server (IP from either internal or OVHcloud network)
        :param pulumi.Input[builtins.bool] backup: is it a backup server used in case of failure of all the non-backup backends
        :param pulumi.Input[builtins.str] display_name: Label for the server
        :param pulumi.Input[builtins.int] farm_id: ID of the farm this server is attached to
        :param pulumi.Input[builtins.str] on_marked_down: enable action when backend marked down. (`shutdown-sessions`)
        :param pulumi.Input[builtins.int] port: Port that backend will respond on
        :param pulumi.Input[builtins.bool] probe: defines if backend will be probed to determine health and keep as active in farm if healthy
        :param pulumi.Input[builtins.str] proxy_protocol_version: version of the PROXY protocol used to pass origin connection information from loadbalancer to receiving service (`v1`, `v2`, `v2-ssl`, `v2-ssl-cn`)
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.bool] ssl: is the connection ciphered with SSL (TLS)
        :param pulumi.Input[builtins.str] status: backend status - `active` or `inactive`
        :param pulumi.Input[builtins.int] weight: used in loadbalancing algorithm
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HttpFarmServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a backend server entry linked to HTTP loadbalancing group (farm)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        lb = ovh.IpLoadBalancing.get_ip_load_balancing(service_name="ip-1.2.3.4",
            state="ok")
        farmname = ovh.ip_load_balancing.HttpFarm("farmname",
            service_name=lb.service_name,
            port=8080,
            zone="all")
        backend = ovh.ip_load_balancing.HttpFarmServer("backend",
            service_name=lb.service_name,
            farm_id=farmname.id,
            display_name="mybackend",
            address="4.5.6.7",
            status="active",
            port=80,
            proxy_protocol_version="v2",
            weight=2,
            probe=True,
            ssl=False,
            backup=True)
        ```

        ## Import

        HTTP farm server can be imported using the following format `service_name`, the `id` of the farm and the `id` of the server separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:IpLoadBalancing/httpFarmServer:HttpFarmServer backend service_name/farm_id/server_id
        ```

        :param str resource_name: The name of the resource.
        :param HttpFarmServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HttpFarmServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 backup: Optional[pulumi.Input[builtins.bool]] = None,
                 chain: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 farm_id: Optional[pulumi.Input[builtins.int]] = None,
                 on_marked_down: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 probe: Optional[pulumi.Input[builtins.bool]] = None,
                 proxy_protocol_version: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HttpFarmServerArgs.__new__(HttpFarmServerArgs)

            if address is None and not opts.urn:
                raise TypeError("Missing required property 'address'")
            __props__.__dict__["address"] = address
            __props__.__dict__["backup"] = backup
            __props__.__dict__["chain"] = chain
            __props__.__dict__["display_name"] = display_name
            if farm_id is None and not opts.urn:
                raise TypeError("Missing required property 'farm_id'")
            __props__.__dict__["farm_id"] = farm_id
            __props__.__dict__["on_marked_down"] = on_marked_down
            __props__.__dict__["port"] = port
            __props__.__dict__["probe"] = probe
            __props__.__dict__["proxy_protocol_version"] = proxy_protocol_version
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["ssl"] = ssl
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            __props__.__dict__["weight"] = weight
            __props__.__dict__["cookie"] = None
        super(HttpFarmServer, __self__).__init__(
            'ovh:IpLoadBalancing/httpFarmServer:HttpFarmServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address: Optional[pulumi.Input[builtins.str]] = None,
            backup: Optional[pulumi.Input[builtins.bool]] = None,
            chain: Optional[pulumi.Input[builtins.str]] = None,
            cookie: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            farm_id: Optional[pulumi.Input[builtins.int]] = None,
            on_marked_down: Optional[pulumi.Input[builtins.str]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            probe: Optional[pulumi.Input[builtins.bool]] = None,
            proxy_protocol_version: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            ssl: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            weight: Optional[pulumi.Input[builtins.int]] = None) -> 'HttpFarmServer':
        """
        Get an existing HttpFarmServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] address: Address of the backend server (IP from either internal or OVHcloud network)
        :param pulumi.Input[builtins.bool] backup: is it a backup server used in case of failure of all the non-backup backends
        :param pulumi.Input[builtins.str] cookie: Value of the stickiness cookie used for this backend.
        :param pulumi.Input[builtins.str] display_name: Label for the server
        :param pulumi.Input[builtins.int] farm_id: ID of the farm this server is attached to
        :param pulumi.Input[builtins.str] on_marked_down: enable action when backend marked down. (`shutdown-sessions`)
        :param pulumi.Input[builtins.int] port: Port that backend will respond on
        :param pulumi.Input[builtins.bool] probe: defines if backend will be probed to determine health and keep as active in farm if healthy
        :param pulumi.Input[builtins.str] proxy_protocol_version: version of the PROXY protocol used to pass origin connection information from loadbalancer to receiving service (`v1`, `v2`, `v2-ssl`, `v2-ssl-cn`)
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.bool] ssl: is the connection ciphered with SSL (TLS)
        :param pulumi.Input[builtins.str] status: backend status - `active` or `inactive`
        :param pulumi.Input[builtins.int] weight: used in loadbalancing algorithm
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HttpFarmServerState.__new__(_HttpFarmServerState)

        __props__.__dict__["address"] = address
        __props__.__dict__["backup"] = backup
        __props__.__dict__["chain"] = chain
        __props__.__dict__["cookie"] = cookie
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["farm_id"] = farm_id
        __props__.__dict__["on_marked_down"] = on_marked_down
        __props__.__dict__["port"] = port
        __props__.__dict__["probe"] = probe
        __props__.__dict__["proxy_protocol_version"] = proxy_protocol_version
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["ssl"] = ssl
        __props__.__dict__["status"] = status
        __props__.__dict__["weight"] = weight
        return HttpFarmServer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Output[builtins.str]:
        """
        Address of the backend server (IP from either internal or OVHcloud network)
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter
    def backup(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        is it a backup server used in case of failure of all the non-backup backends
        """
        return pulumi.get(self, "backup")

    @property
    @pulumi.getter
    def chain(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "chain")

    @property
    @pulumi.getter
    def cookie(self) -> pulumi.Output[builtins.str]:
        """
        Value of the stickiness cookie used for this backend.
        """
        return pulumi.get(self, "cookie")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Label for the server
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="farmId")
    def farm_id(self) -> pulumi.Output[builtins.int]:
        """
        ID of the farm this server is attached to
        """
        return pulumi.get(self, "farm_id")

    @property
    @pulumi.getter(name="onMarkedDown")
    def on_marked_down(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        enable action when backend marked down. (`shutdown-sessions`)
        """
        return pulumi.get(self, "on_marked_down")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Port that backend will respond on
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def probe(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        defines if backend will be probed to determine health and keep as active in farm if healthy
        """
        return pulumi.get(self, "probe")

    @property
    @pulumi.getter(name="proxyProtocolVersion")
    def proxy_protocol_version(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        version of the PROXY protocol used to pass origin connection information from loadbalancer to receiving service (`v1`, `v2`, `v2-ssl`, `v2-ssl-cn`)
        """
        return pulumi.get(self, "proxy_protocol_version")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def ssl(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        is the connection ciphered with SSL (TLS)
        """
        return pulumi.get(self, "ssl")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        backend status - `active` or `inactive`
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def weight(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        used in loadbalancing algorithm
        """
        return pulumi.get(self, "weight")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 access_token: Optional[pulumi.Input[builtins.str]] = None,
                 application_key: Optional[pulumi.Input[builtins.str]] = None,
                 application_secret: Optional[pulumi.Input[builtins.str]] = None,
                 client_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_key: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[builtins.str] access_token: The OVH API Access Token
        :param pulumi.Input[builtins.str] application_key: The OVH API Application Key
        :param pulumi.Input[builtins.str] application_secret: The OVH API Application Secret
        :param pulumi.Input[builtins.str] client_id: OAuth 2.0 application's ID
        :param pulumi.Input[builtins.str] client_secret: OAuth 2.0 application's secret
        :param pulumi.Input[builtins.str] consumer_key: The OVH API Consumer Key
        :param pulumi.Input[builtins.str] endpoint: The OVH API endpoint to target (ex: "ovh-eu")
        """
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)
        if application_key is not None:
            pulumi.set(__self__, "application_key", application_key)
        if application_secret is not None:
            pulumi.set(__self__, "application_secret", application_secret)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if consumer_key is not None:
            pulumi.set(__self__, "consumer_key", consumer_key)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The OVH API Access Token
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_token", value)

    @property
    @pulumi.getter(name="applicationKey")
    def application_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The OVH API Application Key
        """
        return pulumi.get(self, "application_key")

    @application_key.setter
    def application_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "application_key", value)

    @property
    @pulumi.getter(name="applicationSecret")
    def application_secret(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The OVH API Application Secret
        """
        return pulumi.get(self, "application_secret")

    @application_secret.setter
    def application_secret(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "application_secret", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OAuth 2.0 application's ID
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OAuth 2.0 application's secret
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="consumerKey")
    def consumer_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The OVH API Consumer Key
        """
        return pulumi.get(self, "consumer_key")

    @consumer_key.setter
    def consumer_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consumer_key", value)

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The OVH API endpoint to target (ex: "ovh-eu")
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[builtins.str]] = None,
                 application_key: Optional[pulumi.Input[builtins.str]] = None,
                 application_secret: Optional[pulumi.Input[builtins.str]] = None,
                 client_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_key: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        The provider type for the ovh package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_token: The OVH API Access Token
        :param pulumi.Input[builtins.str] application_key: The OVH API Application Key
        :param pulumi.Input[builtins.str] application_secret: The OVH API Application Secret
        :param pulumi.Input[builtins.str] client_id: OAuth 2.0 application's ID
        :param pulumi.Input[builtins.str] client_secret: OAuth 2.0 application's secret
        :param pulumi.Input[builtins.str] consumer_key: The OVH API Consumer Key
        :param pulumi.Input[builtins.str] endpoint: The OVH API endpoint to target (ex: "ovh-eu")
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the ovh package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[builtins.str]] = None,
                 application_key: Optional[pulumi.Input[builtins.str]] = None,
                 application_secret: Optional[pulumi.Input[builtins.str]] = None,
                 client_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_key: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["access_token"] = access_token
            __props__.__dict__["application_key"] = application_key
            __props__.__dict__["application_secret"] = application_secret
            __props__.__dict__["client_id"] = client_id
            __props__.__dict__["client_secret"] = client_secret
            __props__.__dict__["consumer_key"] = consumer_key
            __props__.__dict__["endpoint"] = endpoint
        super(Provider, __self__).__init__(
            'ovh',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The OVH API Access Token
        """
        return pulumi.get(self, "access_token")

    @property
    @pulumi.getter(name="applicationKey")
    def application_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The OVH API Application Key
        """
        return pulumi.get(self, "application_key")

    @property
    @pulumi.getter(name="applicationSecret")
    def application_secret(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The OVH API Application Secret
        """
        return pulumi.get(self, "application_secret")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        OAuth 2.0 application's ID
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        OAuth 2.0 application's secret
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter(name="consumerKey")
    def consumer_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The OVH API Consumer Key
        """
        return pulumi.get(self, "consumer_key")

    @property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The OVH API endpoint to target (ex: "ovh-eu")
        """
        return pulumi.get(self, "endpoint")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkPrivateSubnetV2Args', 'NetworkPrivateSubnetV2']

@pulumi.input_type
class NetworkPrivateSubnetV2Args:
    def __init__(__self__, *,
                 cidr: pulumi.Input[builtins.str],
                 network_id: pulumi.Input[builtins.str],
                 region: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 allocation_pools: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2AllocationPoolArgs']]]] = None,
                 dhcp: Optional[pulumi.Input[builtins.bool]] = None,
                 dns_nameservers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 enable_gateway_ip: Optional[pulumi.Input[builtins.bool]] = None,
                 gateway_ip: Optional[pulumi.Input[builtins.str]] = None,
                 host_routes: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2HostRouteArgs']]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 use_default_public_dns_resolver: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a NetworkPrivateSubnetV2 resource.
        :param pulumi.Input[builtins.str] cidr: IP range of the subnet Changing this value recreates the subnet.
        :param pulumi.Input[builtins.str] network_id: The id of the network. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] region: The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2AllocationPoolArgs']]] allocation_pools: List of IP allocation pools Changing this value recreates the resource.
        :param pulumi.Input[builtins.bool] dhcp: Enable DHCP. Changing this forces a new resource to be created. Defaults to true.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dns_nameservers: DNS nameservers used by DHCP Changing this value recreates the resource. Defaults to OVH default DNS nameserver.
        :param pulumi.Input[builtins.bool] enable_gateway_ip: Set to true if you want to set a default gateway IP. Changing this value recreates the resource. Defaults to true.
        :param pulumi.Input[builtins.str] gateway_ip: See Argument Reference above.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2HostRouteArgs']]] host_routes: Static host routes of subnet
        :param pulumi.Input[builtins.str] name: Name of the subnet Changing this value recreates the subnet.
        :param pulumi.Input[builtins.bool] use_default_public_dns_resolver: Set to false if you want to use your DNS resolver. Changing this value recreates the resource.
        """
        pulumi.set(__self__, "cidr", cidr)
        pulumi.set(__self__, "network_id", network_id)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "service_name", service_name)
        if allocation_pools is not None:
            pulumi.set(__self__, "allocation_pools", allocation_pools)
        if dhcp is not None:
            pulumi.set(__self__, "dhcp", dhcp)
        if dns_nameservers is not None:
            pulumi.set(__self__, "dns_nameservers", dns_nameservers)
        if enable_gateway_ip is not None:
            pulumi.set(__self__, "enable_gateway_ip", enable_gateway_ip)
        if gateway_ip is not None:
            pulumi.set(__self__, "gateway_ip", gateway_ip)
        if host_routes is not None:
            pulumi.set(__self__, "host_routes", host_routes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if use_default_public_dns_resolver is not None:
            pulumi.set(__self__, "use_default_public_dns_resolver", use_default_public_dns_resolver)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Input[builtins.str]:
        """
        IP range of the subnet Changing this value recreates the subnet.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Input[builtins.str]:
        """
        The id of the network. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter
    def region(self) -> pulumi.Input[builtins.str]:
        """
        The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="allocationPools")
    def allocation_pools(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2AllocationPoolArgs']]]]:
        """
        List of IP allocation pools Changing this value recreates the resource.
        """
        return pulumi.get(self, "allocation_pools")

    @allocation_pools.setter
    def allocation_pools(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2AllocationPoolArgs']]]]):
        pulumi.set(self, "allocation_pools", value)

    @property
    @pulumi.getter
    def dhcp(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable DHCP. Changing this forces a new resource to be created. Defaults to true.
        """
        return pulumi.get(self, "dhcp")

    @dhcp.setter
    def dhcp(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dhcp", value)

    @property
    @pulumi.getter(name="dnsNameservers")
    def dns_nameservers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        DNS nameservers used by DHCP Changing this value recreates the resource. Defaults to OVH default DNS nameserver.
        """
        return pulumi.get(self, "dns_nameservers")

    @dns_nameservers.setter
    def dns_nameservers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "dns_nameservers", value)

    @property
    @pulumi.getter(name="enableGatewayIp")
    def enable_gateway_ip(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you want to set a default gateway IP. Changing this value recreates the resource. Defaults to true.
        """
        return pulumi.get(self, "enable_gateway_ip")

    @enable_gateway_ip.setter
    def enable_gateway_ip(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_gateway_ip", value)

    @property
    @pulumi.getter(name="gatewayIp")
    def gateway_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "gateway_ip")

    @gateway_ip.setter
    def gateway_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_ip", value)

    @property
    @pulumi.getter(name="hostRoutes")
    def host_routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2HostRouteArgs']]]]:
        """
        Static host routes of subnet
        """
        return pulumi.get(self, "host_routes")

    @host_routes.setter
    def host_routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2HostRouteArgs']]]]):
        pulumi.set(self, "host_routes", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the subnet Changing this value recreates the subnet.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="useDefaultPublicDnsResolver")
    def use_default_public_dns_resolver(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to false if you want to use your DNS resolver. Changing this value recreates the resource.
        """
        return pulumi.get(self, "use_default_public_dns_resolver")

    @use_default_public_dns_resolver.setter
    def use_default_public_dns_resolver(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "use_default_public_dns_resolver", value)


@pulumi.input_type
class _NetworkPrivateSubnetV2State:
    def __init__(__self__, *,
                 allocation_pools: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2AllocationPoolArgs']]]] = None,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 dhcp: Optional[pulumi.Input[builtins.bool]] = None,
                 dns_nameservers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 enable_gateway_ip: Optional[pulumi.Input[builtins.bool]] = None,
                 gateway_ip: Optional[pulumi.Input[builtins.str]] = None,
                 host_routes: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2HostRouteArgs']]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 network_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 use_default_public_dns_resolver: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering NetworkPrivateSubnetV2 resources.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2AllocationPoolArgs']]] allocation_pools: List of IP allocation pools Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] cidr: IP range of the subnet Changing this value recreates the subnet.
        :param pulumi.Input[builtins.bool] dhcp: Enable DHCP. Changing this forces a new resource to be created. Defaults to true.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dns_nameservers: DNS nameservers used by DHCP Changing this value recreates the resource. Defaults to OVH default DNS nameserver.
        :param pulumi.Input[builtins.bool] enable_gateway_ip: Set to true if you want to set a default gateway IP. Changing this value recreates the resource. Defaults to true.
        :param pulumi.Input[builtins.str] gateway_ip: See Argument Reference above.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2HostRouteArgs']]] host_routes: Static host routes of subnet
        :param pulumi.Input[builtins.str] name: Name of the subnet Changing this value recreates the subnet.
        :param pulumi.Input[builtins.str] network_id: The id of the network. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] region: The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.bool] use_default_public_dns_resolver: Set to false if you want to use your DNS resolver. Changing this value recreates the resource.
        """
        if allocation_pools is not None:
            pulumi.set(__self__, "allocation_pools", allocation_pools)
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if dhcp is not None:
            pulumi.set(__self__, "dhcp", dhcp)
        if dns_nameservers is not None:
            pulumi.set(__self__, "dns_nameservers", dns_nameservers)
        if enable_gateway_ip is not None:
            pulumi.set(__self__, "enable_gateway_ip", enable_gateway_ip)
        if gateway_ip is not None:
            pulumi.set(__self__, "gateway_ip", gateway_ip)
        if host_routes is not None:
            pulumi.set(__self__, "host_routes", host_routes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if use_default_public_dns_resolver is not None:
            pulumi.set(__self__, "use_default_public_dns_resolver", use_default_public_dns_resolver)

    @property
    @pulumi.getter(name="allocationPools")
    def allocation_pools(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2AllocationPoolArgs']]]]:
        """
        List of IP allocation pools Changing this value recreates the resource.
        """
        return pulumi.get(self, "allocation_pools")

    @allocation_pools.setter
    def allocation_pools(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2AllocationPoolArgs']]]]):
        pulumi.set(self, "allocation_pools", value)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP range of the subnet Changing this value recreates the subnet.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter
    def dhcp(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable DHCP. Changing this forces a new resource to be created. Defaults to true.
        """
        return pulumi.get(self, "dhcp")

    @dhcp.setter
    def dhcp(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dhcp", value)

    @property
    @pulumi.getter(name="dnsNameservers")
    def dns_nameservers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        DNS nameservers used by DHCP Changing this value recreates the resource. Defaults to OVH default DNS nameserver.
        """
        return pulumi.get(self, "dns_nameservers")

    @dns_nameservers.setter
    def dns_nameservers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "dns_nameservers", value)

    @property
    @pulumi.getter(name="enableGatewayIp")
    def enable_gateway_ip(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you want to set a default gateway IP. Changing this value recreates the resource. Defaults to true.
        """
        return pulumi.get(self, "enable_gateway_ip")

    @enable_gateway_ip.setter
    def enable_gateway_ip(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_gateway_ip", value)

    @property
    @pulumi.getter(name="gatewayIp")
    def gateway_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "gateway_ip")

    @gateway_ip.setter
    def gateway_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_ip", value)

    @property
    @pulumi.getter(name="hostRoutes")
    def host_routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2HostRouteArgs']]]]:
        """
        Static host routes of subnet
        """
        return pulumi.get(self, "host_routes")

    @host_routes.setter
    def host_routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetV2HostRouteArgs']]]]):
        pulumi.set(self, "host_routes", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the subnet Changing this value recreates the subnet.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the network. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="useDefaultPublicDnsResolver")
    def use_default_public_dns_resolver(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to false if you want to use your DNS resolver. Changing this value recreates the resource.
        """
        return pulumi.get(self, "use_default_public_dns_resolver")

    @use_default_public_dns_resolver.setter
    def use_default_public_dns_resolver(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "use_default_public_dns_resolver", value)


class NetworkPrivateSubnetV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allocation_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2AllocationPoolArgs', 'NetworkPrivateSubnetV2AllocationPoolArgsDict']]]]] = None,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 dhcp: Optional[pulumi.Input[builtins.bool]] = None,
                 dns_nameservers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 enable_gateway_ip: Optional[pulumi.Input[builtins.bool]] = None,
                 gateway_ip: Optional[pulumi.Input[builtins.str]] = None,
                 host_routes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2HostRouteArgs', 'NetworkPrivateSubnetV2HostRouteArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 network_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 use_default_public_dns_resolver: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        Creates a subnet in a private network of a public cloud region.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        subnet = ovh.cloud_project.NetworkPrivateSubnetV2("subnet",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            network_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            name="my_private_subnet",
            region="XXX1",
            dns_nameservers=["1.1.1.1"],
            cidr="192.168.168.0/24",
            dhcp=True,
            enable_gateway_ip=True,
            use_default_public_dns_resolver=False)
        ```

        ## Import

        Subnet in a private network of a public cloud project can be imported using the `service_name`, `region`, `network_id` and `subnet_id`, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/networkPrivateSubnetV2:NetworkPrivateSubnetV2 mysubnet 5ceb661434891538b54a4f2c66fc4b746e/BHS5/25807101-8aaa-4ea5-b507-61f0d661b101/0f0b73a4-403b-45e4-86d0-b438f1291909
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2AllocationPoolArgs', 'NetworkPrivateSubnetV2AllocationPoolArgsDict']]]] allocation_pools: List of IP allocation pools Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] cidr: IP range of the subnet Changing this value recreates the subnet.
        :param pulumi.Input[builtins.bool] dhcp: Enable DHCP. Changing this forces a new resource to be created. Defaults to true.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dns_nameservers: DNS nameservers used by DHCP Changing this value recreates the resource. Defaults to OVH default DNS nameserver.
        :param pulumi.Input[builtins.bool] enable_gateway_ip: Set to true if you want to set a default gateway IP. Changing this value recreates the resource. Defaults to true.
        :param pulumi.Input[builtins.str] gateway_ip: See Argument Reference above.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2HostRouteArgs', 'NetworkPrivateSubnetV2HostRouteArgsDict']]]] host_routes: Static host routes of subnet
        :param pulumi.Input[builtins.str] name: Name of the subnet Changing this value recreates the subnet.
        :param pulumi.Input[builtins.str] network_id: The id of the network. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] region: The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.bool] use_default_public_dns_resolver: Set to false if you want to use your DNS resolver. Changing this value recreates the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkPrivateSubnetV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a subnet in a private network of a public cloud region.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        subnet = ovh.cloud_project.NetworkPrivateSubnetV2("subnet",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            network_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            name="my_private_subnet",
            region="XXX1",
            dns_nameservers=["1.1.1.1"],
            cidr="192.168.168.0/24",
            dhcp=True,
            enable_gateway_ip=True,
            use_default_public_dns_resolver=False)
        ```

        ## Import

        Subnet in a private network of a public cloud project can be imported using the `service_name`, `region`, `network_id` and `subnet_id`, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/networkPrivateSubnetV2:NetworkPrivateSubnetV2 mysubnet 5ceb661434891538b54a4f2c66fc4b746e/BHS5/25807101-8aaa-4ea5-b507-61f0d661b101/0f0b73a4-403b-45e4-86d0-b438f1291909
        ```

        :param str resource_name: The name of the resource.
        :param NetworkPrivateSubnetV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkPrivateSubnetV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allocation_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2AllocationPoolArgs', 'NetworkPrivateSubnetV2AllocationPoolArgsDict']]]]] = None,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 dhcp: Optional[pulumi.Input[builtins.bool]] = None,
                 dns_nameservers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 enable_gateway_ip: Optional[pulumi.Input[builtins.bool]] = None,
                 gateway_ip: Optional[pulumi.Input[builtins.str]] = None,
                 host_routes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2HostRouteArgs', 'NetworkPrivateSubnetV2HostRouteArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 network_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 use_default_public_dns_resolver: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkPrivateSubnetV2Args.__new__(NetworkPrivateSubnetV2Args)

            __props__.__dict__["allocation_pools"] = allocation_pools
            if cidr is None and not opts.urn:
                raise TypeError("Missing required property 'cidr'")
            __props__.__dict__["cidr"] = cidr
            __props__.__dict__["dhcp"] = dhcp
            __props__.__dict__["dns_nameservers"] = dns_nameservers
            __props__.__dict__["enable_gateway_ip"] = enable_gateway_ip
            __props__.__dict__["gateway_ip"] = gateway_ip
            __props__.__dict__["host_routes"] = host_routes
            __props__.__dict__["name"] = name
            if network_id is None and not opts.urn:
                raise TypeError("Missing required property 'network_id'")
            __props__.__dict__["network_id"] = network_id
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["use_default_public_dns_resolver"] = use_default_public_dns_resolver
        super(NetworkPrivateSubnetV2, __self__).__init__(
            'ovh:CloudProject/networkPrivateSubnetV2:NetworkPrivateSubnetV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allocation_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2AllocationPoolArgs', 'NetworkPrivateSubnetV2AllocationPoolArgsDict']]]]] = None,
            cidr: Optional[pulumi.Input[builtins.str]] = None,
            dhcp: Optional[pulumi.Input[builtins.bool]] = None,
            dns_nameservers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            enable_gateway_ip: Optional[pulumi.Input[builtins.bool]] = None,
            gateway_ip: Optional[pulumi.Input[builtins.str]] = None,
            host_routes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2HostRouteArgs', 'NetworkPrivateSubnetV2HostRouteArgsDict']]]]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            network_id: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            use_default_public_dns_resolver: Optional[pulumi.Input[builtins.bool]] = None) -> 'NetworkPrivateSubnetV2':
        """
        Get an existing NetworkPrivateSubnetV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2AllocationPoolArgs', 'NetworkPrivateSubnetV2AllocationPoolArgsDict']]]] allocation_pools: List of IP allocation pools Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] cidr: IP range of the subnet Changing this value recreates the subnet.
        :param pulumi.Input[builtins.bool] dhcp: Enable DHCP. Changing this forces a new resource to be created. Defaults to true.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dns_nameservers: DNS nameservers used by DHCP Changing this value recreates the resource. Defaults to OVH default DNS nameserver.
        :param pulumi.Input[builtins.bool] enable_gateway_ip: Set to true if you want to set a default gateway IP. Changing this value recreates the resource. Defaults to true.
        :param pulumi.Input[builtins.str] gateway_ip: See Argument Reference above.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetV2HostRouteArgs', 'NetworkPrivateSubnetV2HostRouteArgsDict']]]] host_routes: Static host routes of subnet
        :param pulumi.Input[builtins.str] name: Name of the subnet Changing this value recreates the subnet.
        :param pulumi.Input[builtins.str] network_id: The id of the network. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] region: The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.bool] use_default_public_dns_resolver: Set to false if you want to use your DNS resolver. Changing this value recreates the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkPrivateSubnetV2State.__new__(_NetworkPrivateSubnetV2State)

        __props__.__dict__["allocation_pools"] = allocation_pools
        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["dhcp"] = dhcp
        __props__.__dict__["dns_nameservers"] = dns_nameservers
        __props__.__dict__["enable_gateway_ip"] = enable_gateway_ip
        __props__.__dict__["gateway_ip"] = gateway_ip
        __props__.__dict__["host_routes"] = host_routes
        __props__.__dict__["name"] = name
        __props__.__dict__["network_id"] = network_id
        __props__.__dict__["region"] = region
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["use_default_public_dns_resolver"] = use_default_public_dns_resolver
        return NetworkPrivateSubnetV2(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allocationPools")
    def allocation_pools(self) -> pulumi.Output[Sequence['outputs.NetworkPrivateSubnetV2AllocationPool']]:
        """
        List of IP allocation pools Changing this value recreates the resource.
        """
        return pulumi.get(self, "allocation_pools")

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[builtins.str]:
        """
        IP range of the subnet Changing this value recreates the subnet.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter
    def dhcp(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Enable DHCP. Changing this forces a new resource to be created. Defaults to true.
        """
        return pulumi.get(self, "dhcp")

    @property
    @pulumi.getter(name="dnsNameservers")
    def dns_nameservers(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        DNS nameservers used by DHCP Changing this value recreates the resource. Defaults to OVH default DNS nameserver.
        """
        return pulumi.get(self, "dns_nameservers")

    @property
    @pulumi.getter(name="enableGatewayIp")
    def enable_gateway_ip(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Set to true if you want to set a default gateway IP. Changing this value recreates the resource. Defaults to true.
        """
        return pulumi.get(self, "enable_gateway_ip")

    @property
    @pulumi.getter(name="gatewayIp")
    def gateway_ip(self) -> pulumi.Output[builtins.str]:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "gateway_ip")

    @property
    @pulumi.getter(name="hostRoutes")
    def host_routes(self) -> pulumi.Output[Optional[Sequence['outputs.NetworkPrivateSubnetV2HostRoute']]]:
        """
        Static host routes of subnet
        """
        return pulumi.get(self, "host_routes")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the subnet Changing this value recreates the subnet.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the network. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="useDefaultPublicDnsResolver")
    def use_default_public_dns_resolver(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Set to false if you want to use your DNS resolver. Changing this value recreates the resource.
        """
        return pulumi.get(self, "use_default_public_dns_resolver")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetOkmsCredentialResult',
    'AwaitableGetOkmsCredentialResult',
    'get_okms_credential',
    'get_okms_credential_output',
]

@pulumi.output_type
class GetOkmsCredentialResult:
    """
    A collection of values returned by getOkmsCredential.
    """
    def __init__(__self__, certificate_pem=None, created_at=None, description=None, expired_at=None, from_csr=None, id=None, identity_urns=None, name=None, okms_id=None, status=None):
        if certificate_pem and not isinstance(certificate_pem, str):
            raise TypeError("Expected argument 'certificate_pem' to be a str")
        pulumi.set(__self__, "certificate_pem", certificate_pem)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if expired_at and not isinstance(expired_at, str):
            raise TypeError("Expected argument 'expired_at' to be a str")
        pulumi.set(__self__, "expired_at", expired_at)
        if from_csr and not isinstance(from_csr, bool):
            raise TypeError("Expected argument 'from_csr' to be a bool")
        pulumi.set(__self__, "from_csr", from_csr)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identity_urns and not isinstance(identity_urns, list):
            raise TypeError("Expected argument 'identity_urns' to be a list")
        pulumi.set(__self__, "identity_urns", identity_urns)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if okms_id and not isinstance(okms_id, str):
            raise TypeError("Expected argument 'okms_id' to be a str")
        pulumi.set(__self__, "okms_id", okms_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="certificatePem")
    def certificate_pem(self) -> builtins.str:
        """
        (String) PEM encoded certificate of the credential
        """
        return pulumi.get(self, "certificate_pem")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        (String) Creation time of the credential
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        (String) Description of the credential
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expiredAt")
    def expired_at(self) -> builtins.str:
        """
        (String) Expiration time of the credential
        """
        return pulumi.get(self, "expired_at")

    @property
    @pulumi.getter(name="fromCsr")
    def from_csr(self) -> builtins.bool:
        """
        (Boolean) Is the credential generated from CSR
        """
        return pulumi.get(self, "from_csr")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="identityUrns")
    def identity_urns(self) -> Sequence[builtins.str]:
        """
        (List of String) List of identity URNs associated with the credential
        """
        return pulumi.get(self, "identity_urns")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        (String) Name of the credential
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="okmsId")
    def okms_id(self) -> builtins.str:
        return pulumi.get(self, "okms_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        (String) Status of the credential
        """
        return pulumi.get(self, "status")


class AwaitableGetOkmsCredentialResult(GetOkmsCredentialResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOkmsCredentialResult(
            certificate_pem=self.certificate_pem,
            created_at=self.created_at,
            description=self.description,
            expired_at=self.expired_at,
            from_csr=self.from_csr,
            id=self.id,
            identity_urns=self.identity_urns,
            name=self.name,
            okms_id=self.okms_id,
            status=self.status)


def get_okms_credential(id: Optional[builtins.str] = None,
                        okms_id: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOkmsCredentialResult:
    """
    Use this data source to retrieve data associated with a KMS credential, such as the PEM encoded certificate.


    :param builtins.str id: ID of the credential
    :param builtins.str okms_id: ID of the KMS
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['okmsId'] = okms_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Okms/getOkmsCredential:getOkmsCredential', __args__, opts=opts, typ=GetOkmsCredentialResult).value

    return AwaitableGetOkmsCredentialResult(
        certificate_pem=pulumi.get(__ret__, 'certificate_pem'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        expired_at=pulumi.get(__ret__, 'expired_at'),
        from_csr=pulumi.get(__ret__, 'from_csr'),
        id=pulumi.get(__ret__, 'id'),
        identity_urns=pulumi.get(__ret__, 'identity_urns'),
        name=pulumi.get(__ret__, 'name'),
        okms_id=pulumi.get(__ret__, 'okms_id'),
        status=pulumi.get(__ret__, 'status'))
def get_okms_credential_output(id: Optional[pulumi.Input[builtins.str]] = None,
                               okms_id: Optional[pulumi.Input[builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOkmsCredentialResult]:
    """
    Use this data source to retrieve data associated with a KMS credential, such as the PEM encoded certificate.


    :param builtins.str id: ID of the credential
    :param builtins.str okms_id: ID of the KMS
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['okmsId'] = okms_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Okms/getOkmsCredential:getOkmsCredential', __args__, opts=opts, typ=GetOkmsCredentialResult)
    return __ret__.apply(lambda __response__: GetOkmsCredentialResult(
        certificate_pem=pulumi.get(__response__, 'certificate_pem'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        expired_at=pulumi.get(__response__, 'expired_at'),
        from_csr=pulumi.get(__response__, 'from_csr'),
        id=pulumi.get(__response__, 'id'),
        identity_urns=pulumi.get(__response__, 'identity_urns'),
        name=pulumi.get(__response__, 'name'),
        okms_id=pulumi.get(__response__, 'okms_id'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LogsOutputOpenSearchAliasArgs', 'LogsOutputOpenSearchAlias']

@pulumi.input_type
class LogsOutputOpenSearchAliasArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 suffix: pulumi.Input[builtins.str],
                 indexes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 nb_index: Optional[pulumi.Input[builtins.int]] = None,
                 nb_stream: Optional[pulumi.Input[builtins.int]] = None,
                 streams: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a LogsOutputOpenSearchAlias resource.
        :param pulumi.Input[builtins.str] description: Index description
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] suffix: Index suffix
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] indexes: List of attached indexes id
        :param pulumi.Input[builtins.int] nb_index: Number of indices linked
        :param pulumi.Input[builtins.int] nb_stream: Number of streams linked
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] streams: List of attached streams id
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "suffix", suffix)
        if indexes is not None:
            pulumi.set(__self__, "indexes", indexes)
        if nb_index is not None:
            pulumi.set(__self__, "nb_index", nb_index)
        if nb_stream is not None:
            pulumi.set(__self__, "nb_stream", nb_stream)
        if streams is not None:
            pulumi.set(__self__, "streams", streams)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[builtins.str]:
        """
        Index description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def suffix(self) -> pulumi.Input[builtins.str]:
        """
        Index suffix
        """
        return pulumi.get(self, "suffix")

    @suffix.setter
    def suffix(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "suffix", value)

    @property
    @pulumi.getter
    def indexes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of attached indexes id
        """
        return pulumi.get(self, "indexes")

    @indexes.setter
    def indexes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "indexes", value)

    @property
    @pulumi.getter(name="nbIndex")
    def nb_index(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of indices linked
        """
        return pulumi.get(self, "nb_index")

    @nb_index.setter
    def nb_index(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_index", value)

    @property
    @pulumi.getter(name="nbStream")
    def nb_stream(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of streams linked
        """
        return pulumi.get(self, "nb_stream")

    @nb_stream.setter
    def nb_stream(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_stream", value)

    @property
    @pulumi.getter
    def streams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of attached streams id
        """
        return pulumi.get(self, "streams")

    @streams.setter
    def streams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "streams", value)


@pulumi.input_type
class _LogsOutputOpenSearchAliasState:
    def __init__(__self__, *,
                 alias_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 current_size: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 indexes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 is_editable: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 nb_index: Optional[pulumi.Input[builtins.int]] = None,
                 nb_stream: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 streams: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 suffix: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LogsOutputOpenSearchAlias resources.
        :param pulumi.Input[builtins.str] alias_id: Alias Id
        :param pulumi.Input[builtins.str] created_at: Alias creation
        :param pulumi.Input[builtins.int] current_size: Current alias size (in bytes)
        :param pulumi.Input[builtins.str] description: Index description
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] indexes: List of attached indexes id
        :param pulumi.Input[builtins.bool] is_editable: Indicates if you are allowed to edit entry
        :param pulumi.Input[builtins.str] name: Alias name
        :param pulumi.Input[builtins.int] nb_index: Number of indices linked
        :param pulumi.Input[builtins.int] nb_stream: Number of streams linked
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] streams: List of attached streams id
        :param pulumi.Input[builtins.str] suffix: Index suffix
        :param pulumi.Input[builtins.str] updated_at: Input last update
        """
        if alias_id is not None:
            pulumi.set(__self__, "alias_id", alias_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if current_size is not None:
            pulumi.set(__self__, "current_size", current_size)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if indexes is not None:
            pulumi.set(__self__, "indexes", indexes)
        if is_editable is not None:
            pulumi.set(__self__, "is_editable", is_editable)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nb_index is not None:
            pulumi.set(__self__, "nb_index", nb_index)
        if nb_stream is not None:
            pulumi.set(__self__, "nb_stream", nb_stream)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if streams is not None:
            pulumi.set(__self__, "streams", streams)
        if suffix is not None:
            pulumi.set(__self__, "suffix", suffix)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="aliasId")
    def alias_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alias Id
        """
        return pulumi.get(self, "alias_id")

    @alias_id.setter
    def alias_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alias_id", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alias creation
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="currentSize")
    def current_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Current alias size (in bytes)
        """
        return pulumi.get(self, "current_size")

    @current_size.setter
    def current_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "current_size", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Index description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def indexes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of attached indexes id
        """
        return pulumi.get(self, "indexes")

    @indexes.setter
    def indexes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "indexes", value)

    @property
    @pulumi.getter(name="isEditable")
    def is_editable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates if you are allowed to edit entry
        """
        return pulumi.get(self, "is_editable")

    @is_editable.setter
    def is_editable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_editable", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alias name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nbIndex")
    def nb_index(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of indices linked
        """
        return pulumi.get(self, "nb_index")

    @nb_index.setter
    def nb_index(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_index", value)

    @property
    @pulumi.getter(name="nbStream")
    def nb_stream(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of streams linked
        """
        return pulumi.get(self, "nb_stream")

    @nb_stream.setter
    def nb_stream(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_stream", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def streams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of attached streams id
        """
        return pulumi.get(self, "streams")

    @streams.setter
    def streams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "streams", value)

    @property
    @pulumi.getter
    def suffix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Index suffix
        """
        return pulumi.get(self, "suffix")

    @suffix.setter
    def suffix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "suffix", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input last update
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


class LogsOutputOpenSearchAlias(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 indexes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 nb_index: Optional[pulumi.Input[builtins.int]] = None,
                 nb_stream: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 streams: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 suffix: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a DBaaS Logs Opensearch output alias.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        alias = ovh.dbaas.LogsOutputOpenSearchAlias("alias",
            service_name="....",
            description="my opensearch alias",
            suffix="alias")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Index description
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] indexes: List of attached indexes id
        :param pulumi.Input[builtins.int] nb_index: Number of indices linked
        :param pulumi.Input[builtins.int] nb_stream: Number of streams linked
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] streams: List of attached streams id
        :param pulumi.Input[builtins.str] suffix: Index suffix
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogsOutputOpenSearchAliasArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a DBaaS Logs Opensearch output alias.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        alias = ovh.dbaas.LogsOutputOpenSearchAlias("alias",
            service_name="....",
            description="my opensearch alias",
            suffix="alias")
        ```

        :param str resource_name: The name of the resource.
        :param LogsOutputOpenSearchAliasArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogsOutputOpenSearchAliasArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 indexes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 nb_index: Optional[pulumi.Input[builtins.int]] = None,
                 nb_stream: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 streams: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 suffix: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogsOutputOpenSearchAliasArgs.__new__(LogsOutputOpenSearchAliasArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            __props__.__dict__["indexes"] = indexes
            __props__.__dict__["nb_index"] = nb_index
            __props__.__dict__["nb_stream"] = nb_stream
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["streams"] = streams
            if suffix is None and not opts.urn:
                raise TypeError("Missing required property 'suffix'")
            __props__.__dict__["suffix"] = suffix
            __props__.__dict__["alias_id"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["current_size"] = None
            __props__.__dict__["is_editable"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["updated_at"] = None
        super(LogsOutputOpenSearchAlias, __self__).__init__(
            'ovh:Dbaas/logsOutputOpenSearchAlias:LogsOutputOpenSearchAlias',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alias_id: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            current_size: Optional[pulumi.Input[builtins.int]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            indexes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            is_editable: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            nb_index: Optional[pulumi.Input[builtins.int]] = None,
            nb_stream: Optional[pulumi.Input[builtins.int]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            streams: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            suffix: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'LogsOutputOpenSearchAlias':
        """
        Get an existing LogsOutputOpenSearchAlias resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] alias_id: Alias Id
        :param pulumi.Input[builtins.str] created_at: Alias creation
        :param pulumi.Input[builtins.int] current_size: Current alias size (in bytes)
        :param pulumi.Input[builtins.str] description: Index description
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] indexes: List of attached indexes id
        :param pulumi.Input[builtins.bool] is_editable: Indicates if you are allowed to edit entry
        :param pulumi.Input[builtins.str] name: Alias name
        :param pulumi.Input[builtins.int] nb_index: Number of indices linked
        :param pulumi.Input[builtins.int] nb_stream: Number of streams linked
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] streams: List of attached streams id
        :param pulumi.Input[builtins.str] suffix: Index suffix
        :param pulumi.Input[builtins.str] updated_at: Input last update
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogsOutputOpenSearchAliasState.__new__(_LogsOutputOpenSearchAliasState)

        __props__.__dict__["alias_id"] = alias_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["current_size"] = current_size
        __props__.__dict__["description"] = description
        __props__.__dict__["indexes"] = indexes
        __props__.__dict__["is_editable"] = is_editable
        __props__.__dict__["name"] = name
        __props__.__dict__["nb_index"] = nb_index
        __props__.__dict__["nb_stream"] = nb_stream
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["streams"] = streams
        __props__.__dict__["suffix"] = suffix
        __props__.__dict__["updated_at"] = updated_at
        return LogsOutputOpenSearchAlias(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aliasId")
    def alias_id(self) -> pulumi.Output[builtins.str]:
        """
        Alias Id
        """
        return pulumi.get(self, "alias_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Alias creation
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="currentSize")
    def current_size(self) -> pulumi.Output[builtins.int]:
        """
        Current alias size (in bytes)
        """
        return pulumi.get(self, "current_size")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Index description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def indexes(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of attached indexes id
        """
        return pulumi.get(self, "indexes")

    @property
    @pulumi.getter(name="isEditable")
    def is_editable(self) -> pulumi.Output[builtins.bool]:
        """
        Indicates if you are allowed to edit entry
        """
        return pulumi.get(self, "is_editable")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Alias name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nbIndex")
    def nb_index(self) -> pulumi.Output[builtins.int]:
        """
        Number of indices linked
        """
        return pulumi.get(self, "nb_index")

    @property
    @pulumi.getter(name="nbStream")
    def nb_stream(self) -> pulumi.Output[builtins.int]:
        """
        Number of streams linked
        """
        return pulumi.get(self, "nb_stream")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def streams(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of attached streams id
        """
        return pulumi.get(self, "streams")

    @property
    @pulumi.getter
    def suffix(self) -> pulumi.Output[builtins.str]:
        """
        Index suffix
        """
        return pulumi.get(self, "suffix")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Input last update
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OpensearchPatternArgs', 'OpensearchPattern']

@pulumi.input_type
class OpensearchPatternArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 pattern: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 max_index_count: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a OpensearchPattern resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] pattern: Pattern format.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.int] max_index_count: Maximum number of index for this pattern.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "pattern", pattern)
        pulumi.set(__self__, "service_name", service_name)
        if max_index_count is not None:
            pulumi.set(__self__, "max_index_count", max_index_count)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def pattern(self) -> pulumi.Input[builtins.str]:
        """
        Pattern format.
        """
        return pulumi.get(self, "pattern")

    @pattern.setter
    def pattern(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "pattern", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="maxIndexCount")
    def max_index_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum number of index for this pattern.
        """
        return pulumi.get(self, "max_index_count")

    @max_index_count.setter
    def max_index_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_index_count", value)


@pulumi.input_type
class _OpensearchPatternState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_index_count: Optional[pulumi.Input[builtins.int]] = None,
                 pattern: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering OpensearchPattern resources.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.int] max_index_count: Maximum number of index for this pattern.
        :param pulumi.Input[builtins.str] pattern: Pattern format.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if max_index_count is not None:
            pulumi.set(__self__, "max_index_count", max_index_count)
        if pattern is not None:
            pulumi.set(__self__, "pattern", pattern)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="maxIndexCount")
    def max_index_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum number of index for this pattern.
        """
        return pulumi.get(self, "max_index_count")

    @max_index_count.setter
    def max_index_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_index_count", value)

    @property
    @pulumi.getter
    def pattern(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Pattern format.
        """
        return pulumi.get(self, "pattern")

    @pattern.setter
    def pattern(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "pattern", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


class OpensearchPattern(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_index_count: Optional[pulumi.Input[builtins.int]] = None,
                 pattern: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a pattern for a opensearch cluster associated with a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        opensearch = ovh.CloudProjectDatabase.get_database(service_name="XXX",
            engine="opensearch",
            id="ZZZ")
        pattern = ovh.cloud_project_database.OpensearchPattern("pattern",
            service_name=opensearch.service_name,
            cluster_id=opensearch.id,
            max_index_count=2,
            pattern="logs_*")
        ```

        ## Import

        OVHcloud Managed opensearch clusters patterns can be imported using the `service_name`, `cluster_id` and `id` of the pattern, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/opensearchPattern:OpensearchPattern my_pattern service_name/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.int] max_index_count: Maximum number of index for this pattern.
        :param pulumi.Input[builtins.str] pattern: Pattern format.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OpensearchPatternArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a pattern for a opensearch cluster associated with a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        opensearch = ovh.CloudProjectDatabase.get_database(service_name="XXX",
            engine="opensearch",
            id="ZZZ")
        pattern = ovh.cloud_project_database.OpensearchPattern("pattern",
            service_name=opensearch.service_name,
            cluster_id=opensearch.id,
            max_index_count=2,
            pattern="logs_*")
        ```

        ## Import

        OVHcloud Managed opensearch clusters patterns can be imported using the `service_name`, `cluster_id` and `id` of the pattern, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/opensearchPattern:OpensearchPattern my_pattern service_name/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param OpensearchPatternArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OpensearchPatternArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_index_count: Optional[pulumi.Input[builtins.int]] = None,
                 pattern: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OpensearchPatternArgs.__new__(OpensearchPatternArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["max_index_count"] = max_index_count
            if pattern is None and not opts.urn:
                raise TypeError("Missing required property 'pattern'")
            __props__.__dict__["pattern"] = pattern
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
        super(OpensearchPattern, __self__).__init__(
            'ovh:CloudProjectDatabase/opensearchPattern:OpensearchPattern',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            max_index_count: Optional[pulumi.Input[builtins.int]] = None,
            pattern: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'OpensearchPattern':
        """
        Get an existing OpensearchPattern resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.int] max_index_count: Maximum number of index for this pattern.
        :param pulumi.Input[builtins.str] pattern: Pattern format.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OpensearchPatternState.__new__(_OpensearchPatternState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["max_index_count"] = max_index_count
        __props__.__dict__["pattern"] = pattern
        __props__.__dict__["service_name"] = service_name
        return OpensearchPattern(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="maxIndexCount")
    def max_index_count(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Maximum number of index for this pattern.
        """
        return pulumi.get(self, "max_index_count")

    @property
    @pulumi.getter
    def pattern(self) -> pulumi.Output[builtins.str]:
        """
        Pattern format.
        """
        return pulumi.get(self, "pattern")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIdentityGroupsResult',
    'AwaitableGetIdentityGroupsResult',
    'get_identity_groups',
    'get_identity_groups_output',
]

@pulumi.output_type
class GetIdentityGroupsResult:
    """
    A collection of values returned by getIdentityGroups.
    """
    def __init__(__self__, groups=None, id=None):
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def groups(self) -> Sequence[builtins.str]:
        """
        The list of the group names of all the identity groups.
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetIdentityGroupsResult(GetIdentityGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdentityGroupsResult(
            groups=self.groups,
            id=self.id)


def get_identity_groups(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdentityGroupsResult:
    """
    Use this data source to retrieve the list of the account's identity groups

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    groups = ovh.Me.get_identity_groups()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Me/getIdentityGroups:getIdentityGroups', __args__, opts=opts, typ=GetIdentityGroupsResult).value

    return AwaitableGetIdentityGroupsResult(
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'))
def get_identity_groups_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdentityGroupsResult]:
    """
    Use this data source to retrieve the list of the account's identity groups

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    groups = ovh.Me.get_identity_groups()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Me/getIdentityGroups:getIdentityGroups', __args__, opts=opts, typ=GetIdentityGroupsResult)
    return __ret__.apply(lambda __response__: GetIdentityGroupsResult(
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ZoneRedirectionArgs', 'ZoneRedirection']

@pulumi.input_type
class ZoneRedirectionArgs:
    def __init__(__self__, *,
                 target: pulumi.Input[builtins.str],
                 type: pulumi.Input[builtins.str],
                 zone: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 keywords: Optional[pulumi.Input[builtins.str]] = None,
                 subdomain: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ZoneRedirection resource.
        :param pulumi.Input[builtins.str] target: The value of the redirection
        :param pulumi.Input[builtins.str] type: The type of the redirection, with values:
        :param pulumi.Input[builtins.str] zone: The domain to add the redirection to
        :param pulumi.Input[builtins.str] description: A description of this redirection
        :param pulumi.Input[builtins.str] keywords: Keywords to describe this redirection
        :param pulumi.Input[builtins.str] subdomain: The name of the redirection
        :param pulumi.Input[builtins.str] title: Title of this redirection
        """
        pulumi.set(__self__, "target", target)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if keywords is not None:
            pulumi.set(__self__, "keywords", keywords)
        if subdomain is not None:
            pulumi.set(__self__, "subdomain", subdomain)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter
    def target(self) -> pulumi.Input[builtins.str]:
        """
        The value of the redirection
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        The type of the redirection, with values:
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[builtins.str]:
        """
        The domain to add the redirection to
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A description of this redirection
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def keywords(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Keywords to describe this redirection
        """
        return pulumi.get(self, "keywords")

    @keywords.setter
    def keywords(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keywords", value)

    @property
    @pulumi.getter
    def subdomain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the redirection
        """
        return pulumi.get(self, "subdomain")

    @subdomain.setter
    def subdomain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subdomain", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Title of this redirection
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "title", value)


@pulumi.input_type
class _ZoneRedirectionState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 keywords: Optional[pulumi.Input[builtins.str]] = None,
                 subdomain: Optional[pulumi.Input[builtins.str]] = None,
                 target: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ZoneRedirection resources.
        :param pulumi.Input[builtins.str] description: A description of this redirection
        :param pulumi.Input[builtins.str] keywords: Keywords to describe this redirection
        :param pulumi.Input[builtins.str] subdomain: The name of the redirection
        :param pulumi.Input[builtins.str] target: The value of the redirection
        :param pulumi.Input[builtins.str] title: Title of this redirection
        :param pulumi.Input[builtins.str] type: The type of the redirection, with values:
        :param pulumi.Input[builtins.str] zone: The domain to add the redirection to
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if keywords is not None:
            pulumi.set(__self__, "keywords", keywords)
        if subdomain is not None:
            pulumi.set(__self__, "subdomain", subdomain)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A description of this redirection
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def keywords(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Keywords to describe this redirection
        """
        return pulumi.get(self, "keywords")

    @keywords.setter
    def keywords(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keywords", value)

    @property
    @pulumi.getter
    def subdomain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the redirection
        """
        return pulumi.get(self, "subdomain")

    @subdomain.setter
    def subdomain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subdomain", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The value of the redirection
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Title of this redirection
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the redirection, with values:
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The domain to add the redirection to
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone", value)


class ZoneRedirection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 keywords: Optional[pulumi.Input[builtins.str]] = None,
                 subdomain: Optional[pulumi.Input[builtins.str]] = None,
                 target: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a OVHcloud domain zone redirection.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        # Add a redirection to a sub-domain
        test = ovh.domain.ZoneRedirection("test",
            zone="testdemo.ovh",
            subdomain="test",
            type="visiblePermanent",
            target="http://www.ovh")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: A description of this redirection
        :param pulumi.Input[builtins.str] keywords: Keywords to describe this redirection
        :param pulumi.Input[builtins.str] subdomain: The name of the redirection
        :param pulumi.Input[builtins.str] target: The value of the redirection
        :param pulumi.Input[builtins.str] title: Title of this redirection
        :param pulumi.Input[builtins.str] type: The type of the redirection, with values:
        :param pulumi.Input[builtins.str] zone: The domain to add the redirection to
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ZoneRedirectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a OVHcloud domain zone redirection.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        # Add a redirection to a sub-domain
        test = ovh.domain.ZoneRedirection("test",
            zone="testdemo.ovh",
            subdomain="test",
            type="visiblePermanent",
            target="http://www.ovh")
        ```

        :param str resource_name: The name of the resource.
        :param ZoneRedirectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ZoneRedirectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 keywords: Optional[pulumi.Input[builtins.str]] = None,
                 subdomain: Optional[pulumi.Input[builtins.str]] = None,
                 target: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ZoneRedirectionArgs.__new__(ZoneRedirectionArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["keywords"] = keywords
            __props__.__dict__["subdomain"] = subdomain
            if target is None and not opts.urn:
                raise TypeError("Missing required property 'target'")
            __props__.__dict__["target"] = target
            __props__.__dict__["title"] = title
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            if zone is None and not opts.urn:
                raise TypeError("Missing required property 'zone'")
            __props__.__dict__["zone"] = zone
        super(ZoneRedirection, __self__).__init__(
            'ovh:Domain/zoneRedirection:ZoneRedirection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            keywords: Optional[pulumi.Input[builtins.str]] = None,
            subdomain: Optional[pulumi.Input[builtins.str]] = None,
            target: Optional[pulumi.Input[builtins.str]] = None,
            title: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            zone: Optional[pulumi.Input[builtins.str]] = None) -> 'ZoneRedirection':
        """
        Get an existing ZoneRedirection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: A description of this redirection
        :param pulumi.Input[builtins.str] keywords: Keywords to describe this redirection
        :param pulumi.Input[builtins.str] subdomain: The name of the redirection
        :param pulumi.Input[builtins.str] target: The value of the redirection
        :param pulumi.Input[builtins.str] title: Title of this redirection
        :param pulumi.Input[builtins.str] type: The type of the redirection, with values:
        :param pulumi.Input[builtins.str] zone: The domain to add the redirection to
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ZoneRedirectionState.__new__(_ZoneRedirectionState)

        __props__.__dict__["description"] = description
        __props__.__dict__["keywords"] = keywords
        __props__.__dict__["subdomain"] = subdomain
        __props__.__dict__["target"] = target
        __props__.__dict__["title"] = title
        __props__.__dict__["type"] = type
        __props__.__dict__["zone"] = zone
        return ZoneRedirection(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A description of this redirection
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def keywords(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Keywords to describe this redirection
        """
        return pulumi.get(self, "keywords")

    @property
    @pulumi.getter
    def subdomain(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the redirection
        """
        return pulumi.get(self, "subdomain")

    @property
    @pulumi.getter
    def target(self) -> pulumi.Output[builtins.str]:
        """
        The value of the redirection
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Title of this redirection
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the redirection, with values:
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[builtins.str]:
        """
        The domain to add the redirection to
        """
        return pulumi.get(self, "zone")

